==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PrefixDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputGroupItemDescriptionMetadata } from "./InputGroupItemDescriptionMetadata";
import { PrefixDescription } from "./PrefixDescription";
/**
 * @hidden
 */
export let PrefixDescriptionMetadata = /*@__PURE__*/ (() => {
    class PrefixDescriptionMetadata extends Base {
        static b(a) {
            if (PrefixDescriptionMetadata.a == null) {
                PrefixDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PrefixDescriptionMetadata.c(PrefixDescriptionMetadata.a);
            }
            if (a.k(PrefixDescriptionMetadata.a)) {
                return;
            }
            a.ab(PrefixDescriptionMetadata.a);
        }
        static c(a) {
            InputGroupItemDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:XPrefix");
            a.item("Id", "String");
            a.item("AriaLabel", "String");
            a.item("IsHover", "Boolean");
            a.item("Disabled", "(w:IsDisabled,xam:IsDisabled,wf:IsDisabled)Boolean");
        }
        static d(a) {
            PrefixDescriptionMetadata.b(a);
            a.ad("Prefix", () => new PrefixDescription());
            a.ac("Prefix", PrefixDescriptionMetadata.a);
        }
    }
    PrefixDescriptionMetadata.$t = markType(PrefixDescriptionMetadata, 'PrefixDescriptionMetadata');
    PrefixDescriptionMetadata.a = null;
    return PrefixDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PrefixDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputGroupItemDescriptionMetadata } from "./InputGroupItemDescriptionMetadata";
import { PrefixDescription } from "./PrefixDescription";
/**
 * @hidden
 */
export let PrefixDescriptionMetadata = /*@__PURE__*/ (() => {
    class PrefixDescriptionMetadata extends Base {
        static b(a) {
            if (PrefixDescriptionMetadata.a == null) {
                PrefixDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PrefixDescriptionMetadata.c(PrefixDescriptionMetadata.a);
            }
            if (a.k(PrefixDescriptionMetadata.a)) {
                return;
            }
            a.ac(PrefixDescriptionMetadata.a);
        }
        static c(a) {
            InputGroupItemDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:XPrefix");
            a.item("Id", "String");
            a.item("AriaLabel", "String");
            a.item("IsHover", "Boolean");
            a.item("Disabled", "(w:IsDisabled,xam:IsDisabled,wf:IsDisabled)Boolean");
        }
        static d(a) {
            PrefixDescriptionMetadata.b(a);
            a.ae("Prefix", () => new PrefixDescription());
            a.ad("Prefix", PrefixDescriptionMetadata.a);
        }
    }
    PrefixDescriptionMetadata.$t = markType(PrefixDescriptionMetadata, 'PrefixDescriptionMetadata');
    PrefixDescriptionMetadata.a = null;
    return PrefixDescriptionMetadata;
})();
